%define         icap_user c-icap
%define         icap_group c-icap

Name:           c-icap
Version:        0.5.6
Release:        2%{dist}
Summary:        HTTP proxy ICAP server

License:        LGPLv2+
URL:            http://c-icap.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/c_icap-%{version}.tar.gz
Source1:        %{name}.logrotate
Source2:        %{name}.service
Source3:        %{name}.tmpfiles
# PATCH-FIX-openSUSE -- Use user and group 'c-icap' explicitely
Patch3:         c-icap-use_c-icap_user_and_group_in_config.patch
Patch5:         c_icap-0.3.2-missing-call-to-setgroups-before-setuid.patch

# For autoreconf
BuildRequires:  libtool
BuildRequires:  bzip2-devel
BuildRequires:  libdb-devel
BuildRequires:  libmemcached-devel
BuildRequires:  openldap-devel
%if 0%{?fedora} >= 26
BuildRequires:  compat-openssl10-devel
%else
BuildRequires:  openssl-devel
%endif
BuildRequires:  pcre-devel
BuildRequires:  zlib-devel
# For devel docs
BuildRequires:  doxygen
BuildRequires:  pkgconfig
BuildRequires:  systemd

%description
c-icap is an implementation of an ICAP server. It can be used with HTTP
proxies that support the ICAP protocol to implement content adaptation and
filtering services.

Most of the commercial HTTP proxies must support the ICAP protocol. The open
source Squid 3.x proxy server supports it. 


%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       openssl-devel

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q -n c_icap-%{version}
%patch3 -p1
%patch5 -p1
find -name Makefile.am | xargs sed -i -e 's/-rdynamic -rpath @libdir@//'
sed -i "s|%{_prefix}/local/c-icap/etc|%{_sysconfdir}/%{name}|g; \
        s|@prefix@%{_sysconfdir}/c-icap.magic|%{_sysconfdir}/%{name}/c-icap.magic|g; \
        s|%{_localstatedir}/tmp|/tmp|g; \
        s|@prefix@/lib/c_icap|@libexecdir@/c_icap|g; \
        s|@prefix@%{_localstatedir}/log/|%{_localstatedir}/log/%{name}/|g;" \
        c-icap.conf.in

%build
# To reamove rpath
autoreconf -f -i
%configure --disable-static --sysconfdir=%{_sysconfdir}/%{name} \
           --enable-large-files \
           --enable-ipv6 \
           --enable-sysvipc
%make_build
%make_build doc


%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'
chmod -x %{buildroot}%{_sysconfdir}/%{name}/*
mkdir -p %{buildroot}%{_datadir}/c_icap/templates
install -Dm 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
mkdir -p %{buildroot}/%{_datadir}/c_icap/templates/
mkdir -p %{buildroot}%{_localstatedir}/log/%{name}
install -Dm 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install -Dm 0644 %{SOURCE3} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf

%check
cd tests
for test in test_*
do
# test_body and test_tables takes args, no instructions on how to run
  [ -x $test -a $test != test_body -a $test != test_tables ] && ./$test
done

%pre
%{_bindir}/getent group %{icap_group} >/dev/null || %{_sbindir}/groupadd -r %{icap_group} || :
%{_bindir}/getent passwd %{icap_user} >/dev/null || %{_sbindir}/useradd -r -d %{_localstatedir}/lib/%{icap_user} -s /bin/false -c "ICAP server user" -g %{icap_group} %{icap_user} || :

%post
/sbin/ldconfig
systemd-tmpfiles --create %{_prefix}/lib/tmpfiles.d/%{name}.conf
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
/sbin/ldconfig
%systemd_postun %{name}.service

%files
%defattr(-,root,root)
%doc AUTHORS README contrib
%license COPYING
%config(noreplace) %{_sysconfdir}/%{name}/c-icap.conf
%config(noreplace) %{_sysconfdir}/%{name}/c-icap.magic
%config %{_sysconfdir}/%{name}/c-icap.conf.default
%config %{_sysconfdir}/%{name}/c-icap.magic.default
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_unitdir}/%{name}.service
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_bindir}/c-icap
%{_bindir}/c-icap-client
%{_bindir}/c-icap-mkbdb
%{_bindir}/c-icap-stretch
%{_libdir}/*.so.5*
%{_libdir}/c_icap/
%{_datadir}/c_icap/
%{_mandir}/man8/c-icap.8*
%{_mandir}/man8/c-icap-client.8*
%{_mandir}/man8/c-icap-mkbdb.8*
%{_mandir}/man8/c-icap-stretch.8*
%attr(-,%{icap_user},%{icap_group}) %{_localstatedir}/log/%{name}

%files devel
%{_bindir}/c-icap-config
%{_bindir}/c-icap-libicapapi-config
%{_includedir}/*
%{_libdir}/*.so
%{_mandir}/man8/c-icap-config.8*
%{_mandir}/man8/c-icap-libicapapi-config.8*


%changelog
* Sun Feb 23 2020 Giuseppe Ragusa <giuseppe.ragusa@fastmail.fm> - 0.5.6-2
- Corrected scriptlets

* Fri Feb 21 2020 Giuseppe Ragusa <giuseppe.ragusa@fastmail.fm> - 0.5.6-1
- Updated to version 0.5.6
- Backported spec tweaks from SUSE Leap 15.2 package

* Fri Jul 14 2017 Orion Poplawski <orion@cora.nwra.com> - 0.5.2-1
- Initial package
